/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 3.0.13
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.xapian;

public class LatLongMetric {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected LatLongMetric(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(LatLongMetric obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        XapianJNI.delete_LatLongMetric(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  protected void swigDirectorDisconnect() {
    swigCMemOwn = false;
    delete();
  }

  public void swigReleaseOwnership() {
    swigCMemOwn = false;
    XapianJNI.LatLongMetric_change_ownership(this, swigCPtr, false);
  }

  public void swigTakeOwnership() {
    swigCMemOwn = true;
    XapianJNI.LatLongMetric_change_ownership(this, swigCPtr, true);
  }

  public double pointwiseDistance(LatLongCoord a, LatLongCoord b) {
    return XapianJNI.LatLongMetric_pointwiseDistance(swigCPtr, this, LatLongCoord.getCPtr(a), a, LatLongCoord.getCPtr(b), b);
  }

  public double apply(LatLongCoords a, LatLongCoords b) {
    return XapianJNI.LatLongMetric_apply__SWIG_0(swigCPtr, this, LatLongCoords.getCPtr(a), a, LatLongCoords.getCPtr(b), b);
  }

  public double apply(LatLongCoords a, String b) {
    return XapianJNI.LatLongMetric_apply__SWIG_1(swigCPtr, this, LatLongCoords.getCPtr(a), a, b);
  }

  public double apply(LatLongCoords a, String b_ptr, long b_len) {
    return XapianJNI.LatLongMetric_apply__SWIG_2(swigCPtr, this, LatLongCoords.getCPtr(a), a, b_ptr, b_len);
  }

  public String name() {
    return XapianJNI.LatLongMetric_name(swigCPtr, this);
  }

  public LatLongMetric() {
    this(XapianJNI.new_LatLongMetric(), true);
    XapianJNI.LatLongMetric_director_connect(this, swigCPtr, swigCMemOwn, true);
  }

}
