/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 3.0.13
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.xapian;

public class NumberRangeProcessor extends RangeProcessor {
  private transient long swigCPtr;

  protected NumberRangeProcessor(long cPtr, boolean cMemoryOwn) {
    super(XapianJNI.NumberRangeProcessor_SWIGUpcast(cPtr), cMemoryOwn);
    swigCPtr = cPtr;
  }

  protected static long getCPtr(NumberRangeProcessor obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        XapianJNI.delete_NumberRangeProcessor(swigCPtr);
      }
      swigCPtr = 0;
    }
    super.delete();
  }

  public NumberRangeProcessor(int slot_, String str_, long flags_) {
    this(XapianJNI.new_NumberRangeProcessor__SWIG_0(slot_, str_, flags_), true);
  }

  public NumberRangeProcessor(int slot_, String str_) {
    this(XapianJNI.new_NumberRangeProcessor__SWIG_1(slot_, str_), true);
  }

  public NumberRangeProcessor(int slot_) {
    this(XapianJNI.new_NumberRangeProcessor__SWIG_2(slot_), true);
  }

  public Query apply(String begin, String end) {
    return new Query(XapianJNI.NumberRangeProcessor_apply(swigCPtr, this, begin, end), true);
  }

}
