/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 3.0.13
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.xapian;

public class ExpandDeciderAnd extends ExpandDecider {
  private transient long swigCPtr;

  protected ExpandDeciderAnd(long cPtr, boolean cMemoryOwn) {
    super(XapianJNI.ExpandDeciderAnd_SWIGUpcast(cPtr), cMemoryOwn);
    swigCPtr = cPtr;
  }

  protected static long getCPtr(ExpandDeciderAnd obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        XapianJNI.delete_ExpandDeciderAnd(swigCPtr);
      }
      swigCPtr = 0;
    }
    super.delete();
  }

  public ExpandDeciderAnd(ExpandDecider first_, ExpandDecider second_) {
    this(XapianJNI.new_ExpandDeciderAnd(ExpandDecider.getCPtr(first_), first_, ExpandDecider.getCPtr(second_), second_), true);
  }

  public boolean accept(String term) {
    return XapianJNI.ExpandDeciderAnd_accept(swigCPtr, this, term);
  }

}
